####
popbill.py
####
popbill 1.51.0

팝빌 API for Python.

.. image:: https://api.travis-ci.org/linkhub-sdk/popbill.py.svg?branch=master
        :target: https://travis-ci.org/linkhub-sdk/popbill.py

* requirements

  * Python 2.6+
  * linkhub

************
Installation
************

Install via pip:

::

    $ pip install popbill

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/popbill.py.git
    $ cd popbill.py
    $ python setup.py install

사이트
-------------------------------
`Pypi <https://pypi.python.org/pypi/popbill/>`_,
`링크허브(Linkhub) <https://www.linkhub.co.kr/>`_,
`팝빌(Popbill) <https://www.popbill.com/>`_,
